import type { Application, Handler, Router } from 'express';
import { OpenAPISpecification } from './openapi';
import type { ExpressOpenAPIPlugin } from './plugins';
export { OpenAPISpecification } from './openapi';
export type { ExpressOpenAPIPlugin, ExpressOpenAPIPluginInternals, RouteProcessor, } from './plugins';
export { SpecificationPlugin } from './plugins/specification';
export type { Request, RequestHandler, RequestSegmentType, Response, ResponseSegmentType, SpecificationSchema, } from './plugins/specification';
export type { HttpMethod, RequestSegment, ResponseSegment } from './types';
export { setupResponseValidation, validateRequest } from './utils';
export { RequestValidationError, ResponseValidationError } from './zod';
export declare class ExpressOpenAPI {
    private plugins;
    private useStringStashKey;
    private specification;
    constructor({ specification, useStringStashKey, }?: {
        specification?: OpenAPISpecification;
        /**
         * if you're using a library that dynamically modifies your middlewares
         * and the `populateSpecification` method is not working properly,
         * then set this to `true`
         */
        useStringStashKey?: boolean;
    });
    registerPlugin: <StashType, GetMiddleware extends (...params: any[]) => Handler | Handler[]>(plugin: ExpressOpenAPIPlugin<StashType, GetMiddleware>) => (...params: Parameters<GetMiddleware>) => ReturnType<GetMiddleware>;
    populateSpecification: (app: Application | Router, basePath?: string) => OpenAPISpecification;
}
