import type { Application, Router } from 'express';
import type { RegisteredExpressOpenAPIPlugin } from '../plugins';
import type { HttpMethod } from '../types';
import type { OpenAPISpecification } from './specification';
interface Key {
    name: string | number;
    prefix: string;
    suffix: string;
    pattern: string;
    modifier: string;
}
interface Layer {
    handle: Router | ((...params: any[]) => any);
    params?: Record<string, any>;
    path?: string;
    keys: Key[];
    regexp: RegExp & {
        fast_star?: boolean;
        fast_slash?: boolean;
    };
}
interface RouteLayer extends Layer {
    name: string;
    method: HttpMethod;
}
export interface Route {
    path: string | string[];
    stack: RouteLayer[];
    methods: {
        [method in HttpMethod | '_all']?: boolean;
    };
}
export declare const processExpressRouters: (spec: OpenAPISpecification, app: Application | Router, basePath: string | undefined, plugins: RegisteredExpressOpenAPIPlugin[]) => void;
export {};
