import type { ComponentsObject, ExternalDocumentationObject, InfoObject, OpenAPIObject, OperationObject, ParameterObject, ReferenceObject, RequestBodyObject, ResponseObject, SecurityRequirementObject, ServerObject, TagObject } from 'openapi3-ts';
import type { HttpMethod } from '../types';
type ComponentType = 'schemas' | 'responses' | 'parameters' | 'examples' | 'requestBodies' | 'headers' | 'securitySchemes' | 'links' | 'callbacks';
type ComponentObject<Type extends ComponentType = ComponentType> = NonNullable<ComponentsObject[Type]>[string];
type PathItemObject = {
    summary?: string;
    description?: string;
    servers?: ServerObject[];
    parameters?: (ParameterObject | ReferenceObject)[];
} & {
    [method in HttpMethod]?: OperationObject;
};
type PathsObject = {
    [path: string]: PathItemObject | undefined;
};
type OpenAPIObjectSkeleton = {
    openapi: string;
    info: InfoObject;
    components: Required<Pick<ComponentsObject, ComponentType>>;
    paths: PathsObject;
    security: SecurityRequirementObject[];
    tags: TagObject[];
    servers: ServerObject[];
    externalDocs?: ExternalDocumentationObject;
};
export declare class OpenAPISpecification {
    private spec;
    private static isValidOpenApiVersion;
    private assertNonNull;
    constructor({ openapi, info, components, paths, security, tags, servers, externalDocs, }?: OpenAPIObject);
    get openapi(): OpenAPIObjectSkeleton['openapi'];
    setOpenApiVersion(version: string): this;
    get info(): OpenAPIObjectSkeleton['info'];
    setInfo(info: InfoObject): this;
    get components(): OpenAPIObjectSkeleton['components'];
    setComponent<Type extends ComponentType>(componentType: Type, name: string, component: ComponentObject<Type>): this;
    get paths(): OpenAPIObjectSkeleton['paths'];
    getPathItem(path: string): PathItemObject | null;
    setPathItem(path: string, pathItem: PathItemObject): this;
    addPathItemParameter(path: string, parameter: ParameterObject | ReferenceObject): this;
    addPathItemServer(path: string, server: ServerObject): this;
    getPathItemOperation(path: string, method: HttpMethod): OperationObject | null;
    setPathItemOperation(path: string, method: HttpMethod, operation: OperationObject): this;
    setPathItemOperationRequestBody(path: string, method: HttpMethod, requestBody: RequestBodyObject | ReferenceObject): this;
    getPathItemOperationResponse(path: string, method: HttpMethod, httpStatusCode: number | 'default'): ResponseObject | ReferenceObject | null;
    setPathItemOperationResponse(path: string, method: HttpMethod, httpStatusCode: number | 'default', response: ResponseObject | ReferenceObject): this;
    addPathItemOperationTag(path: string, method: HttpMethod, tag: string): this;
    addPathItemOperationParameter(path: string, method: HttpMethod, parameter: ParameterObject | ReferenceObject): this;
    addPathItemOperationSecurityRequirement(path: string, method: HttpMethod, securityRequirement: SecurityRequirementObject): this;
    addPathItemOperationServer(path: string, method: HttpMethod, server: ServerObject): this;
    get security(): OpenAPIObjectSkeleton['security'];
    addSecurity(security: SecurityRequirementObject): this;
    get tags(): OpenAPIObjectSkeleton['tags'];
    addTag(tag: TagObject): this;
    get servers(): OpenAPIObjectSkeleton['servers'];
    addServer(server: ServerObject): this;
    get externalDocs(): OpenAPIObjectSkeleton['externalDocs'];
    setExternalDocs(externalDocs: ExternalDocumentationObject): OpenAPISpecification;
    toJSON(): OpenAPIObject;
    toString(replacer?: Parameters<JSON['stringify']>[1], space?: Parameters<JSON['stringify']>[2]): string;
}
export {};
